/*
 * Copyright 2017-2022 MicroEJ Corp. This file has been modified and/or created by MicroEJ Corp.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation. The Copyright holder(s) designates
 * this particular file as subject to the "Classpath" exception as provided
 * by the Copyright holder(s) in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact the Copyright holder(s) if you need additional information
 * or have any questions.
 * (if Oracle: 500 Oracle Parkway, Redwood Shores, CA 94065 USA or visit www.oracle.com)
 */

package com.is2t.support.security;

import java.security.PublicKey;

/**
 *
 */
public class NativePublicKey extends NativeKey implements PublicKey {

	private static final long serialVersionUID = 1L;

	private byte[] encodedData;
	private boolean encoded;

	/**
	 * @param nativeId
	 *            native resource id.
	 * @param alg
	 *            algorithm name.
	 */
	public NativePublicKey(int nativeId, String alg) {
		super(nativeId, alg);
	}

	@Override
	public String getFormat() {
		return "X.509";
	}

	@Override
	public byte[] getEncoded() {
		if (this.encoded) {
			return this.encodedData;
		}

		int maxSize = nativeGetEncodedMaxSize(this.nativeId);
		byte[] output = new byte[maxSize];
		int length = nativeGetEncoded(this.nativeId, output, output.length);

		this.encodedData = new byte[length];
		System.arraycopy(output, 0, this.encodedData, 0, length);
		this.encoded = true;
		return this.encodedData;
	}

	/**
	 * Get the max size of the encoded key in ASN.1 (X.509) format.
	 *
	 * @param nativeId
	 *            pointer of the C structure holding the key data
	 * @return the max size of the encoded key in ASN.1 (X.509) format
	 */
	private static native int nativeGetEncodedMaxSize(int nativeId);

	/**
	 * Encode the public key to ASN.1 (X.509) format.
	 *
	 * @param nativeId
	 *            pointer of the C structure holding the key data
	 * @param output
	 *            byte array to hold the encoding result initialized with a length equals to
	 *            {@link NativePublicKey}{@link #nativeGetEncodedMaxSize(int)}
	 * @param outputLength
	 *            the output length
	 * @return the real size of the encoded key data in ASN.1 (X.509) format
	 */
	private static native int nativeGetEncoded(int nativeId, byte[] output, int outputLength);

}
