/*
 * Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
 * Copyright 2015-2022 MicroEJ Corp. This file has been modified and/or created by MicroEJ Corp.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation. The Copyright holder(s) designates
 * this particular file as subject to the "Classpath" exception as provided
 * by the Copyright holder(s) in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact the Copyright holder(s) if you need additional information
 * or have any questions.
 * (if Oracle: 500 Oracle Parkway, Redwood Shores, CA 94065 USA or visit www.oracle.com)
 */

package com.is2t.support.security.natives;

import com.is2t.support.security.SecurityErrorConstants;

import ej.sni.NativeException;

public class X509CertSupportNatives {

	/**
	 * Parses the given certificate to validate it and returns its encoded format type.
	 *
	 * @param cert
	 *            the certificate buffer
	 * @param off
	 *            the offset in the buffer at which the certificate content started
	 * @param len
	 *            the certificate content length * @param retry true if this operation is called again when the previous
	 *            call is not completed.
	 * @return the certificate encoded format type (0 if PEM format or 1 if DER format);
	 *         {@link SecurityErrorConstants#J_CERT_PARSE_ERROR} if the certificate is not valid or an error occurs.
	 */
	public static native int parse(byte[] cert, int off, int len);

	/**
	 * Get X509 key from the encoded data
	 *
	 * @param cert
	 *            the encoded certificate data
	 * @param certLen
	 *            encoded data length
	 *
	 * @throws NativeException
	 *             on error.
	 *
	 * @return the resource native id.
	 */
	public static native int getKeyData(byte[] cert, int certLen) throws NativeException;

	/**
	 * Gets the id of the native close function.
	 *
	 * @return the id of the static native close function
	 * @throws NativeException
	 *             on error
	 */
	public static native int nativeGetCloseKeyId();

	/**
	 * Extracts the subject or issuer X500Principal from an X509Certificate.
	 *
	 * @param cert
	 *            The certificate data encoded in X509
	 * @param certLen
	 *            The certificate encoded data length
	 * @param principalData
	 *            The principal data extracted from the certificate.
	 * @param principalDataLength
	 *            The length of principal_data.
	 * @param getIssuer
	 *            '1' to get the issuer, '0' to get the subject.
	 *
	 * @throws NativeException
	 *             on error.
	 *
	 * @return The number of bytes copied into principalData.
	 */
	public static native int getX500PrincipalData(byte[] cert, int certLen, byte[] principalData,
			int principalDataLength, boolean getIssuer) throws NativeException;

	/**
	 * Verify a public key
	 *
	 * @param cert
	 *            the encoded certificate data
	 * @param certLength
	 *            encoded data length
	 * @param nativeId
	 *            the native resource id. the native resource should be the public key to be verified
	 * @return 1 on success
	 * @throws NativeException
	 *             on error
	 */
	public static native int verify(byte[] cert, int certLength, int nativeId) throws NativeException;
}
