/*
 * Java
 *
 * Copyright 2016-2023 MicroEJ Corp. All rights reserved.
 * Use of this source code is governed by a BSD-style license that can be found with this software.
 */
package ej.ecom.wifi.natives;

import java.util.ArrayList;

import ej.ecom.wifi.WPSMode;

/**
 * Wi-Fi WPS mode mapping with native constants.
 */
public class WPSModeNativeConstants {
	/**
	 * No method.
	 */
	public static final int NONE = 0;
	/**
	 * Near Field Communication (NFC) method.
	 */
	public static final int NFC = 1;
	/**
	 * Personal Identification Number (PIN) method.
	 */
	public static final int PIN = 2;
	/**
	 * Push button method.
	 */
	public static final int PUSHBUTTON = 4;
	/**
	 * USB method.
	 */
	public static final int USB = 8;

	public static WPSMode[] convertNativeWPSModeToJavaMode(int mode){
		int[] nativeModes = {WPSModeNativeConstants.NONE, WPSModeNativeConstants.NFC, WPSModeNativeConstants.PIN, WPSModeNativeConstants.PUSHBUTTON, WPSModeNativeConstants.USB};
		int nativeModesLength = nativeModes.length;
		ArrayList<WPSMode> activeModesList = new ArrayList<WPSMode>(0);

		WPSMode[] modesValues = WPSMode.values();
		for(int i = -1; ++i < nativeModesLength;){
			if((mode & nativeModes[i]) == nativeModes[i]){
				activeModesList.add(modesValues[i]);
			}
		}
		WPSMode[] activeModes = new WPSMode[activeModesList.size()];
		return activeModesList.toArray(activeModes);
	}
}
